@@ -3,28 +3,29 @@ import re
 import pandas as pd
 from mkdocs.plugins import BasePlugin
 from mkdocs.config import config_options
+from mkdocs.exceptions import ConfigurationError
 
 from .safe_eval import parse_argkwarg
 
 
 def read_csv(*args, **kwargs):
     df = pd.read_csv(*args, **kwargs)
-    return df.to_markdown(showindex=False, tablefmt="pipe")
+    return df.to_markdown(index=False, tablefmt="pipe")
 
 
 def read_table(*args, **kwargs):
     df = pd.read_table(*args, **kwargs)
-    return df.to_markdown(showindex=False, tablefmt="pipe")
+    return df.to_markdown(index=False, tablefmt="pipe")
 
 
 def read_fwf(*args, **kwargs):
     df = pd.read_fwf(*args, **kwargs)
-    return df.to_markdown(showindex=False, tablefmt="pipe")
+    return df.to_markdown(index=False, tablefmt="pipe")
 
 
 def read_excel(*args, **kwargs):
     df = pd.read_excel(*args, **kwargs)
-    return df.to_markdown(showindex=False, tablefmt="pipe")
+    return df.to_markdown(index=False, tablefmt="pipe")
 
 
 READERS = {
@@ -56,6 +57,24 @@ class TableReaderPlugin(BasePlugin):
 
     config_scheme = (("data_path", config_options.Type(str, default=".")),)
 
+    def on_config(self, config):
+        """
+
+        See https://www.mkdocs.org/user-guide/plugins/#on_config
+        Args:
+            config
+
+        Returns:
+            Config
+        """
+
+        plugins = [p for p in config.get("plugins")]
+
+        if "macros" in plugins:
+            if plugins.index("table-reader") > plugins.index("macros"):
+                raise ConfigurationError("[table-reader]: Incompatible plugin order: Define 'table-reader' before 'macros' in your mkdocs.yml.")
+
+
     def on_page_markdown(self, markdown, page, config, files, **kwargs):
         """
         Replace jinja tag {{ read_csv() }} in markdown with markdown table.
